FramePresentedInfo

Struct FramePresentedInfo 

pub struct FramePresentedInfo {
    pub actual_presentation_time: i64,
    pub presentation_infos: Vec<PresentReceivedInfo>,
    pub num_presents_allowed: u64,
}

Fields

actual_presentation_time: i64

The time the frame was presented to the user. This value was captured after the fact, differentiating it from the presentation_times included in FuturePresentationTimes.

presentation_infos: Vec<PresentReceivedInfo>

The presentation informations for each Present2() that comprised the content of this frame. These are ordered by present submission order.

num_presents_allowed: u64

The number of times remaining that the client can call Present2.